==> soccerwindow2-2.0.0.tar.gz: soccerwindow2-2.0.0/src/qt3/field_canvas.h <==
// -*-c++-*-

/*!
	\file field_canvas.h
	\brief field canvas class Header File.
*/

/*
 *Copyright:

 Copyright (C) Hidehisa AKIYAMA

 This code is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This code is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this code; see the file COPYING.	If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef SOCCERWINDOW2_QT3_FIELD_CANVAS_H
#define SOCCERWINDOW2_QT3_FIELD_CANVAS_H

#include <qwidget.h>
#include <qpixmap.h>

#include "mouse_state.h"

#include <boost/shared_ptr.hpp>

#include <vector>

class QContextMenuEvent;
class QMouseEvent;
class QPaintEvent;
class QPixmap;
class QPointF;
class QPopupMenu;

class MainData;
class PainterInterface;
class FieldPainter;

//! main soccer field canvas class
class FieldCanvas
		: public QWidget {

    Q_OBJECT

private:

    MainData & M_main_data;

    bool M_redraw_all;

    QPopupMenu * M_normal_menu;
    QPopupMenu * M_system_menu;
    QPopupMenu * M_monitor_menu;

    //! 0: left, 1: middle, 2: right
    MouseState M_mouse_state[3];
    QPoint M_measure_ball_speed_point;

    QPixmap M_canvas_pixmap;

    boost::shared_ptr< FieldPainter > M_field_painter;

    std::vector< boost::shared_ptr< PainterInterface > > M_painters;

    // not used
    FieldCanvas( const FieldCanvas & );
    const FieldCanvas & operator=( const FieldCanvas & );

public:

    explicit
    FieldCanvas( MainData & main_data,
                 QWidget * parent );

    ~FieldCanvas();

    void setNormalMenu( QPopupMenu * menu );
    void setSystemMenu( QPopupMenu * menu );
    void setMonitorMenu( QPopupMenu * menu );

    void draw( QPainter & painter );

private:

    void drawMouseMeasure( QPainter & painter );

protected:

    void mouseDoubleClickEvent( QMouseEvent * event );
    void mousePressEvent( QMouseEvent * event );
    void mouseReleaseEvent( QMouseEvent * event );
    void mouseMoveEvent( QMouseEvent * event );

    void paintEvent( QPaintEvent * event );

public slots:

    void setRedrawAllFlag();

    void dropBall();
    void freeKickLeft();
    void freeKickRight();

signals:

    void dropBall( const QPoint & pos );
    void freeKickLeft( const QPoint & pos );
    void freeKickRight( const QPoint & pos );

    void focusChanged( const QPoint & point );
    void mouseMoved( const QPoint & point );

};

#endif

==> soccerwindow2-2.1.1.tar.gz: soccerwindow2-2.1.1/src/qt3/field_canvas.h <==
// -*-c++-*-

/*!
	\file field_canvas.h
	\brief field canvas class Header File.
*/

/*
 *Copyright:

 Copyright (C) Hidehisa AKIYAMA

 This code is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This code is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this code; see the file COPYING.	If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef SOCCERWINDOW2_QT3_FIELD_CANVAS_H
#define SOCCERWINDOW2_QT3_FIELD_CANVAS_H

#include <qwidget.h>
#include <qpixmap.h>

#include "mouse_state.h"

#include <boost/shared_ptr.hpp>

#include <vector>

class QContextMenuEvent;
class QMouseEvent;
class QPaintEvent;
class QPixmap;
class QPointF;
class QPopupMenu;
class QTimer;

class MainData;
class PainterInterface;
class FieldPainter;

//! main soccer field canvas class
class FieldCanvas
		: public QWidget {

    Q_OBJECT

private:

    MainData & M_main_data;

    QPopupMenu * M_normal_menu;
    QPopupMenu * M_system_menu;
    QPopupMenu * M_monitor_menu;

    //! 0: left, 1: middle, 2: right
    MouseState M_mouse_state[3];
    QPoint M_measure_ball_speed_point;

    QTimer * M_cursor_timer;

    QPixmap M_canvas_pixmap;

    boost::shared_ptr< FieldPainter > M_field_painter;

    std::vector< boost::shared_ptr< PainterInterface > > M_painters;

    // not used
    FieldCanvas( const FieldCanvas & );
    const FieldCanvas & operator=( const FieldCanvas & );

public:

    explicit
    FieldCanvas( MainData & main_data,
                 QWidget * parent );

    ~FieldCanvas();

    void setNormalMenu( QPopupMenu * menu );
    void setSystemMenu( QPopupMenu * menu );
    void setMonitorMenu( QPopupMenu * menu );

    void draw( QPainter & painter );

private:

    void drawMouseMeasure( QPainter & painter );

protected:

    void mouseDoubleClickEvent( QMouseEvent * event );
    void mousePressEvent( QMouseEvent * event );
    void mouseReleaseEvent( QMouseEvent * event );
    void mouseMoveEvent( QMouseEvent * event );

    void paintEvent( QPaintEvent * event );

public slots:

    void dropBall();
    void freeKickLeft();
    void freeKickRight();

private slots:

    void hideCursor();

signals:

    void dropBall( const QPoint & pos );
    void freeKickLeft( const QPoint & pos );
    void freeKickRight( const QPoint & pos );

    void focusChanged( const QPoint & point );
    void mouseMoved( const QPoint & point );

};

#endif
